"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file

Copyright 2020-2024 Exactpro (Exactpro Systems Limited)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from th2_grpc_common import common_pb2 as _common_pb2
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class CheckpointRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: _builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: _builtins.int
    description: _builtins.str
    @_builtins.property
    def parent_event_id(self) -> _common_pb2.EventID: ...
    def __init__(
        self,
        *,
        description: _builtins.str = ...,
        parent_event_id: _common_pb2.EventID | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["parent_event_id", b"parent_event_id"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["description", b"description", "parent_event_id", b"parent_event_id"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckpointRequest: _TypeAlias = CheckpointRequest  # noqa: Y015

@_typing.final
class CheckpointResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    CHECKPOINT_FIELD_NUMBER: _builtins.int
    STATUS_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def checkpoint(self) -> _common_pb2.Checkpoint: ...
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    def __init__(
        self,
        *,
        checkpoint: _common_pb2.Checkpoint | None = ...,
        status: _common_pb2.RequestStatus | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["checkpoint", b"checkpoint", "status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["checkpoint", b"checkpoint", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckpointResponse: _TypeAlias = CheckpointResponse  # noqa: Y015

@_typing.final
class ChainID(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    ID_FIELD_NUMBER: _builtins.int
    id: _builtins.str
    def __init__(
        self,
        *,
        id: _builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["id", b"id"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ChainID: _TypeAlias = ChainID  # noqa: Y015

@_typing.final
class CheckRuleRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    CONNECTIVITY_ID_FIELD_NUMBER: _builtins.int
    ROOT_FILTER_FIELD_NUMBER: _builtins.int
    CHECKPOINT_FIELD_NUMBER: _builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: _builtins.int
    TIMEOUT_FIELD_NUMBER: _builtins.int
    STORE_RESULT_FIELD_NUMBER: _builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: _builtins.int
    DESCRIPTION_FIELD_NUMBER: _builtins.int
    DIRECTION_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    BOOK_NAME_FIELD_NUMBER: _builtins.int
    message_timeout: _builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""
    timeout: _builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""
    store_result: _builtins.bool
    """Store the result of the rule for later request by the client"""
    description: _builtins.str
    direction: _common_pb2.Direction.ValueType
    book_name: _builtins.str
    """If it's not set the check will be started from the specified checkpoint otherwise checkpoint will be ignored"""
    @_builtins.property
    def connectivity_id(self) -> _common_pb2.ConnectionID: ...
    @_builtins.property
    def root_filter(self) -> _common_pb2.RootMessageFilter: ...
    @_builtins.property
    def checkpoint(self) -> _common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""

    @_builtins.property
    def parent_event_id(self) -> _common_pb2.EventID: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """The chain id to continue checking."""

    def __init__(
        self,
        *,
        connectivity_id: _common_pb2.ConnectionID | None = ...,
        root_filter: _common_pb2.RootMessageFilter | None = ...,
        checkpoint: _common_pb2.Checkpoint | None = ...,
        message_timeout: _builtins.int = ...,
        timeout: _builtins.int = ...,
        store_result: _builtins.bool = ...,
        parent_event_id: _common_pb2.EventID | None = ...,
        description: _builtins.str = ...,
        direction: _common_pb2.Direction.ValueType = ...,
        chain_id: Global___ChainID | None = ...,
        book_name: _builtins.str = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "parent_event_id", b"parent_event_id", "root_filter", b"root_filter"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["book_name", b"book_name", "chain_id", b"chain_id", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "description", b"description", "direction", b"direction", "message_timeout", b"message_timeout", "parent_event_id", b"parent_event_id", "root_filter", b"root_filter", "store_result", b"store_result", "timeout", b"timeout"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckRuleRequest: _TypeAlias = CheckRuleRequest  # noqa: Y015

@_typing.final
class CheckRuleResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    STATUS_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    RULE_ID_FIELD_NUMBER: _builtins.int
    rule_id: _builtins.int
    """Can be used for requesting response via 'waitForResult' method"""
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""

    def __init__(
        self,
        *,
        status: _common_pb2.RequestStatus | None = ...,
        chain_id: Global___ChainID | None = ...,
        rule_id: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "rule_id", b"rule_id", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckRuleResponse: _TypeAlias = CheckRuleResponse  # noqa: Y015

@_typing.final
class CheckSequenceRuleRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    PRE_FILTER_FIELD_NUMBER: _builtins.int
    ROOT_MESSAGE_FILTERS_FIELD_NUMBER: _builtins.int
    CHECKPOINT_FIELD_NUMBER: _builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: _builtins.int
    TIMEOUT_FIELD_NUMBER: _builtins.int
    STORE_RESULT_FIELD_NUMBER: _builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: _builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: _builtins.int
    CHECK_ORDER_FIELD_NUMBER: _builtins.int
    DESCRIPTION_FIELD_NUMBER: _builtins.int
    DIRECTION_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    SILENCE_CHECK_FIELD_NUMBER: _builtins.int
    BOOK_NAME_FIELD_NUMBER: _builtins.int
    message_timeout: _builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""
    timeout: _builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""
    store_result: _builtins.bool
    """Store the result of the rule for later request by the client"""
    check_order: _builtins.bool
    description: _builtins.str
    direction: _common_pb2.Direction.ValueType
    book_name: _builtins.str
    @_builtins.property
    def pre_filter(self) -> Global___PreFilter: ...
    @_builtins.property
    def root_message_filters(self) -> _containers.RepeatedCompositeFieldContainer[_common_pb2.RootMessageFilter]:
        """
        Either this field or message_filters must be set. If both are set the error response will be received from check1
        """

    @_builtins.property
    def checkpoint(self) -> _common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""

    @_builtins.property
    def connectivity_id(self) -> _common_pb2.ConnectionID: ...
    @_builtins.property
    def parent_event_id(self) -> _common_pb2.EventID: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """The chain id to continue checking."""

    @_builtins.property
    def silence_check(self) -> _wrappers_pb2.BoolValue:
        """If it's not set the check will be started from the specified checkpoint otherwise checkpoint will be ignored"""

    def __init__(
        self,
        *,
        pre_filter: Global___PreFilter | None = ...,
        root_message_filters: _abc.Iterable[_common_pb2.RootMessageFilter] | None = ...,
        checkpoint: _common_pb2.Checkpoint | None = ...,
        message_timeout: _builtins.int = ...,
        timeout: _builtins.int = ...,
        store_result: _builtins.bool = ...,
        connectivity_id: _common_pb2.ConnectionID | None = ...,
        parent_event_id: _common_pb2.EventID | None = ...,
        check_order: _builtins.bool = ...,
        description: _builtins.str = ...,
        direction: _common_pb2.Direction.ValueType = ...,
        chain_id: Global___ChainID | None = ...,
        silence_check: _wrappers_pb2.BoolValue | None = ...,
        book_name: _builtins.str = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "parent_event_id", b"parent_event_id", "pre_filter", b"pre_filter", "silence_check", b"silence_check"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["book_name", b"book_name", "chain_id", b"chain_id", "check_order", b"check_order", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "description", b"description", "direction", b"direction", "message_timeout", b"message_timeout", "parent_event_id", b"parent_event_id", "pre_filter", b"pre_filter", "root_message_filters", b"root_message_filters", "silence_check", b"silence_check", "store_result", b"store_result", "timeout", b"timeout"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckSequenceRuleRequest: _TypeAlias = CheckSequenceRuleRequest  # noqa: Y015

@_typing.final
class CheckSequenceRuleResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    STATUS_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    RULE_ID_FIELD_NUMBER: _builtins.int
    rule_id: _builtins.int
    """Can be used for requesting response via 'waitForResult' method"""
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""

    def __init__(
        self,
        *,
        status: _common_pb2.RequestStatus | None = ...,
        chain_id: Global___ChainID | None = ...,
        rule_id: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "rule_id", b"rule_id", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CheckSequenceRuleResponse: _TypeAlias = CheckSequenceRuleResponse  # noqa: Y015

@_typing.final
class PreFilter(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    @_typing.final
    class FieldsEntry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        KEY_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        key: _builtins.str
        @_builtins.property
        def value(self) -> _common_pb2.ValueFilter: ...
        def __init__(
            self,
            *,
            key: _builtins.str = ...,
            value: _common_pb2.ValueFilter | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    FIELDS_FIELD_NUMBER: _builtins.int
    METADATA_FILTER_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def fields(self) -> _containers.MessageMap[_builtins.str, _common_pb2.ValueFilter]: ...
    @_builtins.property
    def metadata_filter(self) -> _common_pb2.MetadataFilter: ...
    def __init__(
        self,
        *,
        fields: _abc.Mapping[_builtins.str, _common_pb2.ValueFilter] | None = ...,
        metadata_filter: _common_pb2.MetadataFilter | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["metadata_filter", b"metadata_filter"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["fields", b"fields", "metadata_filter", b"metadata_filter"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PreFilter: _TypeAlias = PreFilter  # noqa: Y015

@_typing.final
class NoMessageCheckRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    PRE_FILTER_FIELD_NUMBER: _builtins.int
    MESSAGE_TIMEOUT_FIELD_NUMBER: _builtins.int
    TIMEOUT_FIELD_NUMBER: _builtins.int
    STORE_RESULT_FIELD_NUMBER: _builtins.int
    CHECKPOINT_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: _builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: _builtins.int
    DESCRIPTION_FIELD_NUMBER: _builtins.int
    DIRECTION_FIELD_NUMBER: _builtins.int
    BOOK_NAME_FIELD_NUMBER: _builtins.int
    message_timeout: _builtins.int
    """Timeout to wait for messages after checkpoint. The message's timestamp will be used to compute the timeout"""
    timeout: _builtins.int
    """Timeout for rule execution. Uses the real time to limit the execution of the rule"""
    store_result: _builtins.bool
    """Store the result of the rule for later request by the client"""
    description: _builtins.str
    direction: _common_pb2.Direction.ValueType
    book_name: _builtins.str
    @_builtins.property
    def pre_filter(self) -> Global___PreFilter: ...
    @_builtins.property
    def checkpoint(self) -> _common_pb2.Checkpoint:
        """Registered Checkpoint. If the chain_id is also set in the request the checkpoint will be ignored"""

    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""

    @_builtins.property
    def connectivity_id(self) -> _common_pb2.ConnectionID: ...
    @_builtins.property
    def parent_event_id(self) -> _common_pb2.EventID: ...
    def __init__(
        self,
        *,
        pre_filter: Global___PreFilter | None = ...,
        message_timeout: _builtins.int = ...,
        timeout: _builtins.int = ...,
        store_result: _builtins.bool = ...,
        checkpoint: _common_pb2.Checkpoint | None = ...,
        chain_id: Global___ChainID | None = ...,
        connectivity_id: _common_pb2.ConnectionID | None = ...,
        parent_event_id: _common_pb2.EventID | None = ...,
        description: _builtins.str = ...,
        direction: _common_pb2.Direction.ValueType = ...,
        book_name: _builtins.str = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "parent_event_id", b"parent_event_id", "pre_filter", b"pre_filter"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["book_name", b"book_name", "chain_id", b"chain_id", "checkpoint", b"checkpoint", "connectivity_id", b"connectivity_id", "description", b"description", "direction", b"direction", "message_timeout", b"message_timeout", "parent_event_id", b"parent_event_id", "pre_filter", b"pre_filter", "store_result", b"store_result", "timeout", b"timeout"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___NoMessageCheckRequest: _TypeAlias = NoMessageCheckRequest  # noqa: Y015

@_typing.final
class NoMessageCheckResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    STATUS_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    RULE_ID_FIELD_NUMBER: _builtins.int
    rule_id: _builtins.int
    """Can be used for requesting response via 'waitForResult' method"""
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""

    def __init__(
        self,
        *,
        status: _common_pb2.RequestStatus | None = ...,
        chain_id: Global___ChainID | None = ...,
        rule_id: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "rule_id", b"rule_id", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___NoMessageCheckResponse: _TypeAlias = NoMessageCheckResponse  # noqa: Y015

@_typing.final
class WaitForResultRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: _builtins.int
    TIMEOUT_FIELD_NUMBER: _builtins.int
    rule_id: _builtins.int
    @_builtins.property
    def timeout(self) -> _duration_pb2.Duration:
        """Timeout for waiting for result"""

    def __init__(
        self,
        *,
        rule_id: _builtins.int = ...,
        timeout: _duration_pb2.Duration | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["timeout", b"timeout"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["rule_id", b"rule_id", "timeout", b"timeout"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___WaitForResultRequest: _TypeAlias = WaitForResultRequest  # noqa: Y015

@_typing.final
class WaitForResultResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    STATUS_FIELD_NUMBER: _builtins.int
    RULE_RESULT_FIELD_NUMBER: _builtins.int
    rule_result: _common_pb2.EventStatus.ValueType
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    def __init__(
        self,
        *,
        status: _common_pb2.RequestStatus | None = ...,
        rule_result: _common_pb2.EventStatus.ValueType = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["rule_result", b"rule_result", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___WaitForResultResponse: _TypeAlias = WaitForResultResponse  # noqa: Y015

@_typing.final
class MultiRulesRequest(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    DEFAULT_PARENT_EVENT_ID_FIELD_NUMBER: _builtins.int
    DEFAULT_CHAIN_FIELD_NUMBER: _builtins.int
    RULES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def default_parent_event_id(self) -> _common_pb2.EventID: ...
    @_builtins.property
    def default_chain(self) -> Global___ChainID: ...
    @_builtins.property
    def rules(self) -> _containers.RepeatedCompositeFieldContainer[Global___Rule]: ...
    def __init__(
        self,
        *,
        default_parent_event_id: _common_pb2.EventID | None = ...,
        default_chain: Global___ChainID | None = ...,
        rules: _abc.Iterable[Global___Rule] | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["default_chain", b"default_chain", "default_parent_event_id", b"default_parent_event_id"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["default_chain", b"default_chain", "default_parent_event_id", b"default_parent_event_id", "rules", b"rules"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MultiRulesRequest: _TypeAlias = MultiRulesRequest  # noqa: Y015

@_typing.final
class MultiRulesResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    RESPONSES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def responses(self) -> _containers.RepeatedCompositeFieldContainer[Global___RuleResponse]: ...
    def __init__(
        self,
        *,
        responses: _abc.Iterable[Global___RuleResponse] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["responses", b"responses"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MultiRulesResponse: _TypeAlias = MultiRulesResponse  # noqa: Y015

@_typing.final
class Rule(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    CHECKRULEREQUEST_FIELD_NUMBER: _builtins.int
    SEQUENCERULE_FIELD_NUMBER: _builtins.int
    NOMESSAGERULE_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def checkRuleRequest(self) -> Global___CheckRuleRequest: ...
    @_builtins.property
    def sequenceRule(self) -> Global___CheckSequenceRuleRequest: ...
    @_builtins.property
    def noMessageRule(self) -> Global___NoMessageCheckRequest: ...
    def __init__(
        self,
        *,
        checkRuleRequest: Global___CheckRuleRequest | None = ...,
        sequenceRule: Global___CheckSequenceRuleRequest | None = ...,
        noMessageRule: Global___NoMessageCheckRequest | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["checkRuleRequest", b"checkRuleRequest", "noMessageRule", b"noMessageRule", "one_rule", b"one_rule", "sequenceRule", b"sequenceRule"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["checkRuleRequest", b"checkRuleRequest", "noMessageRule", b"noMessageRule", "one_rule", b"one_rule", "sequenceRule", b"sequenceRule"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_one_rule: _TypeAlias = _typing.Literal["checkRuleRequest", "sequenceRule", "noMessageRule"]  # noqa: Y015
    _WhichOneofArgType_one_rule: _TypeAlias = _typing.Literal["one_rule", b"one_rule"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_one_rule) -> _WhichOneofReturnType_one_rule | None: ...

Global___Rule: _TypeAlias = Rule  # noqa: Y015

@_typing.final
class RuleResponse(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    STATUS_FIELD_NUMBER: _builtins.int
    CHAIN_ID_FIELD_NUMBER: _builtins.int
    RULE_ID_FIELD_NUMBER: _builtins.int
    rule_id: _builtins.int
    """Can be used for requesting response via 'waitForResult' method"""
    @_builtins.property
    def status(self) -> _common_pb2.RequestStatus: ...
    @_builtins.property
    def chain_id(self) -> Global___ChainID:
        """You can use it to unite the next rule to the chain with currently submitted one"""

    def __init__(
        self,
        *,
        status: _common_pb2.RequestStatus | None = ...,
        chain_id: Global___ChainID | None = ...,
        rule_id: _builtins.int = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "status", b"status"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["chain_id", b"chain_id", "rule_id", b"rule_id", "status", b"status"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RuleResponse: _TypeAlias = RuleResponse  # noqa: Y015



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: th2_grpc_check1/check1.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'th2_grpc_check1/check1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cth2_grpc_check1/check1.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cth2_grpc_common/common.proto\"K\n\x11\x43heckpointRequest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\"U\n\x12\x43heckpointResponse\x12\x1f\n\ncheckpoint\x18\x01 \x01(\x0b\x32\x0b.Checkpoint\x12\x1e\n\x06status\x18\x02 \x01(\x0b\x32\x0e.RequestStatus\"\x15\n\x07\x43hainID\x12\n\n\x02id\x18\x01 \x01(\t\"\xd6\x02\n\x10\x43heckRuleRequest\x12&\n\x0f\x63onnectivity_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12\'\n\x0broot_filter\x18\n \x01(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\x0b \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12\x14\n\x0cstore_result\x18\r \x01(\x08\x12!\n\x0fparent_event_id\x18\x06 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1d\n\tdirection\x18\x08 \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x08.ChainID\x12\x11\n\tbook_name\x18\x0c \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"`\n\x11\x43heckRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"\xcf\x03\n\x18\x43heckSequenceRuleRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x30\n\x14root_message_filters\x18\x0c \x03(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\r \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12\x14\n\x0cstore_result\x18\x10 \x01(\x08\x12&\n\x0f\x63onnectivity_id\x18\x05 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x63heck_order\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x1d\n\tdirection\x18\n \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\x0b \x01(\x0b\x32\x08.ChainID\x12\x31\n\rsilence_check\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tbook_name\x18\x0f \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07\"h\n\x19\x43heckSequenceRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"\xa0\x01\n\tPreFilter\x12&\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x16.PreFilter.FieldsEntry\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01J\x04\x08\x01\x10\x02\"\xc6\x02\n\x15NoMessageCheckRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x17\n\x0fmessage_timeout\x18\x02 \x01(\x03\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x14\n\x0cstore_result\x18\x0b \x01(\x08\x12\x1f\n\ncheckpoint\x18\x04 \x01(\x0b\x32\x0b.Checkpoint\x12\x1a\n\x08\x63hain_id\x18\x05 \x01(\x0b\x32\x08.ChainID\x12&\n\x0f\x63onnectivity_id\x18\x06 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\tdirection\x18\t \x01(\x0e\x32\n.Direction\x12\x11\n\tbook_name\x18\n \x01(\t\"e\n\x16NoMessageCheckResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"S\n\x14WaitForResultRequest\x12\x0f\n\x07rule_id\x18\x01 \x01(\x03\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"Z\n\x15WaitForResultResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12!\n\x0brule_result\x18\x02 \x01(\x0e\x32\x0c.EventStatus\"u\n\x11MultiRulesRequest\x12)\n\x17\x64\x65\x66\x61ult_parent_event_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12\x1f\n\rdefault_chain\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x14\n\x05rules\x18\x03 \x03(\x0b\x32\x05.Rule\"6\n\x12MultiRulesResponse\x12 \n\tresponses\x18\x01 \x03(\x0b\x32\r.RuleResponse\"\xa5\x01\n\x04Rule\x12-\n\x10\x63heckRuleRequest\x18\x01 \x01(\x0b\x32\x11.CheckRuleRequestH\x00\x12\x31\n\x0csequenceRule\x18\x02 \x01(\x0b\x32\x19.CheckSequenceRuleRequestH\x00\x12/\n\rnoMessageRule\x18\x03 \x01(\x0b\x32\x16.NoMessageCheckRequestH\x00\x42\n\n\x08one_rule\"[\n\x0cRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\x32\xe9\x03\n\x06\x43heck1\x12=\n\x10\x63reateCheckpoint\x12\x12.CheckpointRequest\x1a\x13.CheckpointResponse\"\x00\x12:\n\x0fsubmitCheckRule\x12\x11.CheckRuleRequest\x1a\x12.CheckRuleResponse\"\x00\x12R\n\x17submitCheckSequenceRule\x12\x19.CheckSequenceRuleRequest\x1a\x1a.CheckSequenceRuleResponse\"\x00\x12I\n\x14submitNoMessageCheck\x12\x16.NoMessageCheckRequest\x1a\x17.NoMessageCheckResponse\"\x00\x12@\n\rwaitForResult\x12\x15.WaitForResultRequest\x1a\x16.WaitForResultResponse\"\x00\x12@\n\x13submitMultipleRules\x12\x12.MultiRulesRequest\x1a\x13.MultiRulesResponse\"\x00\x12\x41\n\x11postMultipleRules\x12\x12.MultiRulesRequest\x1a\x16.google.protobuf.Empty\"\x00\x42 \n\x1c\x63om.exactpro.th2.check1.grpcP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_check1.check1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.exactpro.th2.check1.grpcP\001'
  _globals['_PREFILTER_FIELDSENTRY']._loaded_options = None
  _globals['_PREFILTER_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CHECKPOINTREQUEST']._serialized_start=155
  _globals['_CHECKPOINTREQUEST']._serialized_end=230
  _globals['_CHECKPOINTRESPONSE']._serialized_start=232
  _globals['_CHECKPOINTRESPONSE']._serialized_end=317
  _globals['_CHAINID']._serialized_start=319
  _globals['_CHAINID']._serialized_end=340
  _globals['_CHECKRULEREQUEST']._serialized_start=343
  _globals['_CHECKRULEREQUEST']._serialized_end=685
  _globals['_CHECKRULERESPONSE']._serialized_start=687
  _globals['_CHECKRULERESPONSE']._serialized_end=783
  _globals['_CHECKSEQUENCERULEREQUEST']._serialized_start=786
  _globals['_CHECKSEQUENCERULEREQUEST']._serialized_end=1249
  _globals['_CHECKSEQUENCERULERESPONSE']._serialized_start=1251
  _globals['_CHECKSEQUENCERULERESPONSE']._serialized_end=1355
  _globals['_PREFILTER']._serialized_start=1358
  _globals['_PREFILTER']._serialized_end=1518
  _globals['_PREFILTER_FIELDSENTRY']._serialized_start=1453
  _globals['_PREFILTER_FIELDSENTRY']._serialized_end=1512
  _globals['_NOMESSAGECHECKREQUEST']._serialized_start=1521
  _globals['_NOMESSAGECHECKREQUEST']._serialized_end=1847
  _globals['_NOMESSAGECHECKRESPONSE']._serialized_start=1849
  _globals['_NOMESSAGECHECKRESPONSE']._serialized_end=1950
  _globals['_WAITFORRESULTREQUEST']._serialized_start=1952
  _globals['_WAITFORRESULTREQUEST']._serialized_end=2035
  _globals['_WAITFORRESULTRESPONSE']._serialized_start=2037
  _globals['_WAITFORRESULTRESPONSE']._serialized_end=2127
  _globals['_MULTIRULESREQUEST']._serialized_start=2129
  _globals['_MULTIRULESREQUEST']._serialized_end=2246
  _globals['_MULTIRULESRESPONSE']._serialized_start=2248
  _globals['_MULTIRULESRESPONSE']._serialized_end=2302
  _globals['_RULE']._serialized_start=2305
  _globals['_RULE']._serialized_end=2470
  _globals['_RULERESPONSE']._serialized_start=2472
  _globals['_RULERESPONSE']._serialized_end=2563
  _globals['_CHECK1']._serialized_start=2566
  _globals['_CHECK1']._serialized_end=3055
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_check1 import check1_pb2 as th2__grpc__check1_dot_check1__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in th2_grpc_check1/check1_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class Check1Stub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.createCheckpoint = channel.unary_unary(
                '/Check1/createCheckpoint',
                request_serializer=th2__grpc__check1_dot_check1__pb2.CheckpointRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.CheckpointResponse.FromString,
                _registered_method=True)
        self.submitCheckRule = channel.unary_unary(
                '/Check1/submitCheckRule',
                request_serializer=th2__grpc__check1_dot_check1__pb2.CheckRuleRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.CheckRuleResponse.FromString,
                _registered_method=True)
        self.submitCheckSequenceRule = channel.unary_unary(
                '/Check1/submitCheckSequenceRule',
                request_serializer=th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleResponse.FromString,
                _registered_method=True)
        self.submitNoMessageCheck = channel.unary_unary(
                '/Check1/submitNoMessageCheck',
                request_serializer=th2__grpc__check1_dot_check1__pb2.NoMessageCheckRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.NoMessageCheckResponse.FromString,
                _registered_method=True)
        self.waitForResult = channel.unary_unary(
                '/Check1/waitForResult',
                request_serializer=th2__grpc__check1_dot_check1__pb2.WaitForResultRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.WaitForResultResponse.FromString,
                _registered_method=True)
        self.submitMultipleRules = channel.unary_unary(
                '/Check1/submitMultipleRules',
                request_serializer=th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.SerializeToString,
                response_deserializer=th2__grpc__check1_dot_check1__pb2.MultiRulesResponse.FromString,
                _registered_method=True)
        self.postMultipleRules = channel.unary_unary(
                '/Check1/postMultipleRules',
                request_serializer=th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class Check1Servicer(object):
    """Missing associated documentation comment in .proto file."""

    def createCheckpoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitCheckRule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitCheckSequenceRule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitNoMessageCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def waitForResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def submitMultipleRules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def postMultipleRules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_Check1Servicer_to_server(servicer, server):
    rpc_method_handlers = {
            'createCheckpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.createCheckpoint,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.CheckpointRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.CheckpointResponse.SerializeToString,
            ),
            'submitCheckRule': grpc.unary_unary_rpc_method_handler(
                    servicer.submitCheckRule,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.CheckRuleRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.CheckRuleResponse.SerializeToString,
            ),
            'submitCheckSequenceRule': grpc.unary_unary_rpc_method_handler(
                    servicer.submitCheckSequenceRule,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleResponse.SerializeToString,
            ),
            'submitNoMessageCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.submitNoMessageCheck,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.NoMessageCheckRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.NoMessageCheckResponse.SerializeToString,
            ),
            'waitForResult': grpc.unary_unary_rpc_method_handler(
                    servicer.waitForResult,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.WaitForResultRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.WaitForResultResponse.SerializeToString,
            ),
            'submitMultipleRules': grpc.unary_unary_rpc_method_handler(
                    servicer.submitMultipleRules,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.FromString,
                    response_serializer=th2__grpc__check1_dot_check1__pb2.MultiRulesResponse.SerializeToString,
            ),
            'postMultipleRules': grpc.unary_unary_rpc_method_handler(
                    servicer.postMultipleRules,
                    request_deserializer=th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Check1', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('Check1', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Check1(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def createCheckpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/createCheckpoint',
            th2__grpc__check1_dot_check1__pb2.CheckpointRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.CheckpointResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitCheckRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/submitCheckRule',
            th2__grpc__check1_dot_check1__pb2.CheckRuleRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.CheckRuleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitCheckSequenceRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/submitCheckSequenceRule',
            th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.CheckSequenceRuleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitNoMessageCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/submitNoMessageCheck',
            th2__grpc__check1_dot_check1__pb2.NoMessageCheckRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.NoMessageCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def waitForResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/waitForResult',
            th2__grpc__check1_dot_check1__pb2.WaitForResultRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.WaitForResultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def submitMultipleRules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/submitMultipleRules',
            th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.SerializeToString,
            th2__grpc__check1_dot_check1__pb2.MultiRulesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def postMultipleRules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Check1/postMultipleRules',
            th2__grpc__check1_dot_check1__pb2.MultiRulesRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
